@@ -14,6 +14,7 @@ from mitosheet.api.get_column_describe import get_column_describe
 from mitosheet.api.get_column_dtype import get_column_dtype
 from mitosheet.api.get_datafiles import get_datafiles
 from mitosheet.api.get_dateframe_as_csv import get_dataframe_as_csv
+from mitosheet.api.get_dateframe_as_excel import get_dataframe_as_excel
 from mitosheet.api.get_excel_file_metadata import get_excel_file_metadata
 from mitosheet.api.get_import_summary import get_import_summary
 from mitosheet.api.get_path_contents import get_path_contents
@@ -136,6 +137,8 @@ def handle_api_event(send, event, steps_manager):
         result = get_search_matches(event, steps_manager)
     elif event['type'] == 'get_cell_values':
         result = get_sheet_data(event, steps_manager)
+    elif event['type'] == 'get_dataframe_as_excel':
+        result = get_dataframe_as_excel(event, steps_manager)
     else:
         raise Exception(f'Event: {event} is not a valid API call')
     
