@@ -34,9 +34,9 @@ def get_box_plot(axis, df, column_headers):
     filter_label = ('top 500k') if filtered else ''
     for column_header in column_headers:
         if axis == X:
-            fig.add_trace(go.Box(x=df[column_header], name=(' ').join([column_header, filter_label])))
+            fig.add_trace(go.Box(x=df[column_header], name=(' ').join([str(column_header), filter_label])))
         else:
-            fig.add_trace(go.Box(y=df[column_header], name=(' ').join([column_header, filter_label])))
+            fig.add_trace(go.Box(y=df[column_header], name=(' ').join([str(column_header), filter_label])))
 
     graph_title = get_graph_title(column_headers, [], filtered, BOX)
 
@@ -86,7 +86,7 @@ from mitosheet import filter_df_to_safe_size
 {filtered_code}
 # Add box plots to the graph
 for column_header in {column_headers}:
-    fig.add_trace(go.Box({axis}={df_name}[column_header], name=column_header))
+    fig.add_trace(go.Box({axis}={df_name}[column_header], name=str(column_header)))
 
 # Update the title and stacking mode of the graph
 # See Plotly documentation for customizations: https://plotly.com/python/reference/box/
