@@ -2,6 +2,7 @@
 import io
 from typing import List
 import pandas as pd
+from mitosheet.column_headers import try_make_new_header_valid_if_multi_index_headers
 
 from mitosheet.sheet_functions.types.utils import get_mito_type, NUMBER_SERIES
 
@@ -115,20 +116,20 @@ def get_graph_labels(x_axis_column_headers, y_axis_column_headers):
     elif x_axis_column_headers == [] and y_axis_column_headers != []:
         # Following from the graph generation, if the user only selects a y axis, 
         # then the y axis is the index column and the columns selected are put on the x axis
-        x_axis_title = y_axis_column_headers[0] if len(y_axis_column_headers) == 1 else ''
+        x_axis_title = str(y_axis_column_headers[0]) if len(y_axis_column_headers) == 1 else ''
         y_axis_title = 'index'
 
     elif x_axis_column_headers != [] and y_axis_column_headers == []:
         # Following from the graph generation, if the user only selects a x axis, 
         # then the y axis is the index column
         x_axis_title = 'index'
-        y_axis_title = x_axis_column_headers[0] if len(x_axis_column_headers) == 1 else ''
+        y_axis_title = str(x_axis_column_headers[0]) if len(x_axis_column_headers) == 1 else ''
 
     else: 
         # Only label the axis if there is one column header on the axis. Otherwise, plotly 
         # legend will label the columns
-        x_axis_title = x_axis_column_headers[0] if len(x_axis_column_headers) == 1 else ''
-        y_axis_title = y_axis_column_headers[0] if len(y_axis_column_headers) == 1 else ''
+        x_axis_title = str(x_axis_column_headers[0]) if len(x_axis_column_headers) == 1 else ''
+        y_axis_title = str(y_axis_column_headers[0]) if len(y_axis_column_headers) == 1 else ''
 
     return x_axis_title, y_axis_title
 
@@ -199,15 +200,12 @@ def filter_df_to_safe_size(
     elif graph_type == BAR:
         # If both axises are supplied, then we go on to create the bar chart. 
         # Start by sorting the key column in decreasing frequency so we can filter 
-        # dataframe according to the bar chart filtering strategy. 
-        if other_axis_column_headers is not None and len(other_axis_column_headers) == 1:
-            df['Frequency'] = df.groupby(other_axis_column_headers[0])[other_axis_column_headers[0]].transform('count')
-        else:
-            df['Frequency'] = df.groupby(column_headers[0])[column_headers[0]].transform('count')
+        # dataframe according to the top BAR_CHART_MAX_NUMBER_OF_ROWS
 
-        df = df.sort_values('Frequency', inplace=False, ascending=False)
+        # TODO: this is bugged, with multi-column headers. For now, we just take
+        # the max number of rows
 
-        # Take the top BAR_CHART_MAX_NUMBER_OF_ROWS rows of the sorted dataframe
+        # Take the first BAR_CHART_MAX_NUMBER_OF_ROWS rows
         df = df.head(BAR_CHART_MAX_NUMBER_OF_ROWS)
         
         return df, len(df) < original_df_len
