@@ -235,6 +235,9 @@ def log(log_event, params=None, steps_manager=None):
                     private_params[key] = len(value)
                 else:
                     private_params[key] = value
+            elif 'sheet_index' in key:
+                private_params[key] = value
+                private_params[key + '_df_source'] = steps_manager.curr_step.df_sources[value]
             else:
                 private_params[key] = value
     except:
