@@ -7,13 +7,16 @@
 Main file containing the mito widget.
 """
 import json
+from mitosheet import step_performers
 from mitosheet.saved_analyses.save_utils import read_saved_analysis_names
+from mitosheet.step_performers import STEP_TYPE_TO_USAGE_TRIGGERED_FEEDBACK_ID
 from mitosheet.user.schemas import UJ_FEEDBACKS, UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_RECEIVED_TOURS, UJ_USER_EMAIL
 from mitosheet.user.db import get_user_field
 from mitosheet.utils import get_new_id
 from mitosheet.api import API
 from mitosheet.mito_analytics import log, log_event_processed, log_recent_error
 import pandas as pd
+import random
 
 from ipywidgets import DOMWidget
 import traitlets as t
@@ -58,11 +61,6 @@ class MitoWidget(DOMWidget):
             
         # Set up the state container to hold private widget state
         self.steps_manager = StepsManager(args)
-        
-        # When the widget is first created, it has not been rendered on the frontend yet,
-        # but after it is rendered once, this is set to False. This helps us detect 
-        # when we are rendering for the first time vs. refreshing the sheet
-        self.has_rendered = False
 
         # Set up message handler
         self.on_msg(self.receive_message)
@@ -73,8 +71,8 @@ class MitoWidget(DOMWidget):
         # We store static variables to make writing the shared
         # state variables quicker; we store them so we don't 
         # have to recompute them on each update
-        self.num_feedbacks = len(get_user_field(UJ_FEEDBACKS))
         self.num_usages = len(get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES))
+        self.usage_triggered_feedback_id = ''
         self.is_local_deployment = is_local_deployment()
         self.should_upgrade_mitosheet = should_upgrade_mitosheet()
         self.received_tours = get_user_field(UJ_RECEIVED_TOURS)
@@ -100,11 +98,10 @@ class MitoWidget(DOMWidget):
             'receivedTours': get_user_field(UJ_RECEIVED_TOURS),
             'savedAnalysisNames': read_saved_analysis_names(),
             # Static over a single analysis
-            'hasRendered': self.has_rendered,
             'isLocalDeployment': self.is_local_deployment,
             'shouldUpgradeMitosheet': self.should_upgrade_mitosheet,
-            'numFeedbacks': self.num_feedbacks,
             'numUsages': self.num_usages,
+            'usageTriggeredFeedbackID': self.usage_triggered_feedback_id
         })
 
 
@@ -118,9 +115,13 @@ class MitoWidget(DOMWidget):
         Useful for any event that changes the state of both the sheet
         and the codeblock!
         """
+
         # First, we send this new edit to the evaluator
         self.steps_manager.handle_edit_event(event)
 
+        # Update the usage_triggered_feedback_id variable
+        self.set_usage_triggered_feedback_id()
+
         # We update the state variables 
         self.update_shared_state_variables()
 
@@ -147,10 +148,6 @@ class MitoWidget(DOMWidget):
         - Names of the dataframes
         - Name of an existing analysis
         """
-        # If this is just a message to notify the backend that we have rendered, set and return
-        if event['type'] == 'has_rendered_update':
-            self.has_rendered = True
-            return
 
         self.steps_manager.handle_update_event(event)
 
@@ -241,6 +238,23 @@ class MitoWidget(DOMWidget):
 
         return False
 
+    def set_usage_triggered_feedback_id(self):
+        """
+        Determines if the user should be prompted for feedback. If it determines that we should ask the user for feedback, 
+        then it sets the feedback_id shared variable.
+
+        Current Feedback Strategy:
+        - If the current step type is not the same as the previous step type, then there is a .25% chance that we ask the user for feedback
+        """
+        # If the current step type is not the same as the previous step type, then there is a .25% chance that we ask the user for feedback
+        previous_step_type = self.steps_manager.steps[self.steps_manager.curr_step_idx - 1].step_type if self.steps_manager.curr_step_idx > 1 else None
+        if self.steps_manager.curr_step.step_type != previous_step_type and previous_step_type != 'bulk_old_rename':
+            if random.randint(1, 400) == 1:
+                self.usage_triggered_feedback_id = STEP_TYPE_TO_USAGE_TRIGGERED_FEEDBACK_ID[previous_step_type]
+                return
+
+        self.usage_triggered_feedback_id = ''
+
 def sheet(
         *args,
         view_df=False # We use this param to log if the mitosheet.sheet call is created from the df output button
