@@ -1,46 +1,48 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 """
 For going to a timedelta series.
 """
 
-from typing import Any, Tuple, Union
+from typing import Tuple, Union
 import pandas as pd
 import numpy as np
 
-from mitosheet.sheet_functions.types.utils import is_bool_dtype, is_datetime_dtype, is_number_dtype, is_string_dtype, is_timedelta_dtype
+from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES, DATETIME_SERIES, NUMBER_SERIES, STRING_SERIES, TIMEDELTA_SERIES, get_mito_type
 
 
 def to_timedelta_series(
-        unknown_object: Any,
-        on_uncastable_arg_element: Any=('default', np.NaN), #Union[Literal['error'], Tuple[Literal['default'], any]]
-    ) -> pd.Series:
+        unknown_object,
+        on_uncastable_arg_element=('default', np.NaN), #Union[Literal['error'], Tuple[Literal['default'], any]]
+    ):
     """
     Converts the given object to a timedelta series. Note that on_uncastable_arg_element
     is irrelevant here.
     """
+    from_type = get_mito_type(unknown_object)
 
     # If it is not a series, we put it in a series, and get the type again
-    if not isinstance(unknown_object, pd.Series):
+    if not from_type.endswith('series'):
         unknown_object = pd.Series([unknown_object])
+        from_type = get_mito_type(unknown_object)
 
-    column_dtype = str(unknown_object.dtype)
-    if is_bool_dtype(column_dtype):
+    if from_type == BOOLEAN_SERIES:
         return None
-    elif is_datetime_dtype(column_dtype):
+    elif from_type == DATETIME_SERIES:
         return None
-    elif is_timedelta_dtype(column_dtype):
+    elif from_type == TIMEDELTA_SERIES:
         return unknown_object
-    elif is_number_dtype(column_dtype):
+    elif from_type == NUMBER_SERIES:
         return pd.to_timedelta(
             unknown_object, 
             unit='s',
             errors='coerce'
         )
-    elif is_string_dtype(column_dtype):
+    elif from_type == STRING_SERIES:
         return pd.to_timedelta(
             unknown_object, 
             unit='s',
