@@ -3,7 +3,7 @@
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.column_steps.set_column_formula import SetColumnFormulaStepPerformer
 from mitosheet.step_performers.filter import FilterStepPerformer
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Type
 
 from mitosheet.state import State
 from mitosheet.step_performers import STEP_TYPE_TO_STEP_PERFORMER
@@ -99,7 +99,7 @@ class Step:
         return self.post_state.column_filters
 
     @property
-    def step_performer(self) -> StepPerformer:
+    def step_performer(self) -> Type[StepPerformer]:
         """
         A helper function to return the step performer class
         that is associated with this step, based on step type.
