@@ -10,6 +10,7 @@ how to add a step!
 """
 
 from typing import Dict, List, Type
+from mitosheet.step_performers.drop_duplicates import DropDuplicatesStepPerformer
 from mitosheet.step_performers.import_steps.excel_import import ExcelImportStepPerformer
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.pivot import PivotStepPerformer
@@ -48,7 +49,8 @@ STEP_PERFORMERS: List[Type[StepPerformer]] = [
     DataframeDeleteStepPerformer,
     DataframeDuplicateStepPerformer,
     DataframeRenameStepPerformer,
-    BulkOldRenameStepPerformer
+    BulkOldRenameStepPerformer,
+    DropDuplicatesStepPerformer
 ]
 
 # A helpful mapping for looking up steps based on the incoming events
@@ -62,3 +64,10 @@ STEP_TYPE_TO_STEP_PERFORMER: Dict[str, Type[StepPerformer]] = {
     step_performer.step_type(): step_performer
     for step_performer in STEP_PERFORMERS
 }
+
+# A dictionary mapping step performers to their usage triggered feedback id
+STEP_TYPE_TO_USAGE_TRIGGERED_FEEDBACK_ID: Dict[str, str] = {
+    step_performer.step_type(): step_performer.step_type() + '_usage_triggered'
+    for step_performer in STEP_PERFORMERS
+}
+del STEP_TYPE_TO_USAGE_TRIGGERED_FEEDBACK_ID[BulkOldRenameStepPerformer.step_type()]
