@@ -11,6 +11,7 @@ from mitosheet.errors import make_invalid_column_delete_error
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.topological_sort import topological_sort_columns
+from mitosheet.transpiler.transpile_utils import column_header_list_to_transpiled_code
 
 
 class DeleteColumnStepPerformer(StepPerformer):
@@ -67,11 +68,11 @@ class DeleteColumnStepPerformer(StepPerformer):
     ) -> List[str]:
 
         df_name = post_state.df_names[sheet_index]
-        column_headers = [f'\'{prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)}\'' for column_id in column_ids]
-        column_header_string = (", ").join(column_headers)
+        column_headers_list_string = column_header_list_to_transpiled_code(
+            [prev_state.column_ids.get_column_header_by_id(sheet_index, column_id) for column_id in column_ids]
+        )
 
-        return [f'{df_name}.drop([{column_header_string}], axis=1, inplace=True)']
-    
+        return [f'{df_name}.drop({column_headers_list_string}, axis=1, inplace=True)']
     
     @classmethod
     def describe( # type: ignore
@@ -84,8 +85,8 @@ class DeleteColumnStepPerformer(StepPerformer):
         formated_column_ids = (', '.join(column_ids))
         if df_names is not None:
             df_name = df_names[sheet_index]
-            return f'Deleted column(s) {formated_column_ids} from {df_name}'
-        return f'Deleted column(s) {formated_column_ids}'
+            return f'Deleted column{"s" if len(column_ids) > 1 else ""} {formated_column_ids} from {df_name}'
+        return f'Deleted column{"s" if len(column_ids) > 1 else ""} {formated_column_ids}'
 
 
 def delete_column_ids(
