@@ -9,6 +9,7 @@ from typing import Any, Dict, List, Optional, Tuple
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
+from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
 
 
 def get_valid_index(dfs, sheet_index, new_column_index):
@@ -85,15 +86,16 @@ class ReorderColumnStepPerformer(StepPerformer):
         new_column_index: int
     ) -> List[str]:
         column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+        transpiled_column_header = column_header_to_transpiled_code(column_header)
 
         new_column_index = get_valid_index(prev_state.dfs, sheet_index, new_column_index)
         df_name = post_state.df_names[sheet_index]
 
         # get columns in df
-        columns_list_line = f'{df_name}_columns = [col for col in {df_name}.columns if col != \'{column_header}\']'
+        columns_list_line = f'{df_name}_columns = [col for col in {df_name}.columns if col != {transpiled_column_header}]'
 
         # insert column into correct location 
-        insert_line = f'{df_name}_columns.insert({new_column_index}, \'{column_header}\')'
+        insert_line = f'{df_name}_columns.insert({new_column_index}, {transpiled_column_header})'
         
         # Apply reorder line
         apply_reorder_line = f'{df_name} = {df_name}[{df_name}_columns]'
