@@ -6,6 +6,7 @@
 
 from copy import deepcopy
 import functools
+from mitosheet.sheet_functions.types.utils import get_mito_type
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.state import State
 from numbers import Number
@@ -20,10 +21,9 @@ from mitosheet.sheet_functions.types import (
     STRING_SERIES
 )
 from mitosheet.errors import (
-    make_no_sheet_error,
-    make_no_column_error,
     make_invalid_filter_error
 )
+from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code, list_to_string_without_internal_quotes
 
 # SOME CONSTANTS USED IN THE FILTER STEP ITSELF
 FC_EMPTY = 'empty'
@@ -81,6 +81,132 @@ DATETIME_FILTER_CONDITIONS = [
     FC_DATETIME_LESS_THAN_OR_EQUAL,
 ]
 
+# Dict used when a filter condition is only used by one filter
+FILTER_FORMAT_STRING_DICT = {
+    # SHARED CONDITIONS
+    FC_EMPTY: '{df_name}[{transpiled_column_header}].isna()',
+    FC_NOT_EMPTY: '{df_name}[{transpiled_column_header}].notnull()',
+
+    # BOOLEAN
+    FC_BOOLEAN_IS_TRUE: '{df_name}[{transpiled_column_header}] == True',
+    FC_BOOLEAN_IS_FALSE: '{df_name}[{transpiled_column_header}] == False',
+
+    # NUMBERS
+    FC_NUMBER_EXACTLY: '{df_name}[{transpiled_column_header}] == {value}',
+    FC_NUMBER_NOT_EXACTLY: '{df_name}[{transpiled_column_header}] != {value}',
+    FC_NUMBER_GREATER: '{df_name}[{transpiled_column_header}] > {value}',
+    FC_NUMBER_GREATER_THAN_OR_EQUAL: '{df_name}[{transpiled_column_header}] >= {value}',
+    FC_NUMBER_LESS: '{df_name}[{transpiled_column_header}] < {value}',
+    FC_NUMBER_LESS_THAN_OR_EQUAL: '{df_name}[{transpiled_column_header}] <= {value}',
+    
+    # STRINGS
+    FC_STRING_CONTAINS: '{df_name}[{transpiled_column_header}].str.contains(\'{value}\', na=False)',
+    FC_STRING_DOES_NOT_CONTAIN: '~{df_name}[{transpiled_column_header}].str.contains(\'{value}\', na=False)',
+    FC_STRING_EXACTLY: '{df_name}[{transpiled_column_header}] == \'{value}\'',
+    FC_STRING_NOT_EXACTLY: '{df_name}[{transpiled_column_header}] != \'{value}\'',
+
+    # DATES
+    FC_DATETIME_EXACTLY: '{df_name}[{transpiled_column_header}] == pd.to_datetime(\'{value}\')',
+    FC_DATETIME_NOT_EXACTLY: '{df_name}[{transpiled_column_header}] != pd.to_datetime(\'{value}\')',
+    FC_DATETIME_GREATER: '{df_name}[{transpiled_column_header}] > pd.to_datetime(\'{value}\')',
+    FC_DATETIME_GREATER_THAN_OR_EQUAL: '{df_name}[{transpiled_column_header}] >= pd.to_datetime(\'{value}\')',
+    FC_DATETIME_LESS: '{df_name}[{transpiled_column_header}] < pd.to_datetime(\'{value}\')',
+    FC_DATETIME_LESS_THAN_OR_EQUAL: '{df_name}[{transpiled_column_header}] <= pd.to_datetime(\'{value}\')',            
+}
+
+# Dict used when there a specific filter condition has multiple
+# filters that use it. Helps us write cleaner filter code!
+FILTER_FORMAT_STRING_MULTIPLE_VALUES_DICT = {
+    FC_EMPTY: {
+        'Or': '{df_name}[{transpiled_column_header}].isna()',
+        'And': '{df_name}[{transpiled_column_header}].isna()'
+    },
+    FC_NOT_EMPTY: {
+        'Or': '{df_name}[{transpiled_column_header}].notnull()',
+        'And': '{df_name}[{transpiled_column_header}].notnull()'
+    },
+    FC_BOOLEAN_IS_TRUE: {
+        'Or': '{df_name}[{transpiled_column_header}] == True',
+        'And': '{df_name}[{transpiled_column_header}] == True'
+    },
+    FC_BOOLEAN_IS_FALSE: {
+        'Or': '{df_name}[{transpiled_column_header}] == False',
+        'And': '{df_name}[{transpiled_column_header}] == False'
+    },
+    FC_NUMBER_EXACTLY: {
+        'Or': '{df_name}[{transpiled_column_header}].isin({values})',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val == n for n in {values}))'
+    },
+    FC_NUMBER_NOT_EXACTLY: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val != n for n in {values}))',
+        'And': '~{df_name}[{transpiled_column_header}].isin({values})'
+    },
+    FC_NUMBER_GREATER: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val > n for n in {values}))',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val > n for n in {values}))'
+    },
+    FC_NUMBER_GREATER_THAN_OR_EQUAL: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val >= n for n in {values}))',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val >= n for n in {values}))'
+    },
+    FC_NUMBER_LESS: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val < n for n in {values}))',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val < n for n in {values}))'
+    },
+    FC_NUMBER_LESS_THAN_OR_EQUAL: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val <= n for n in {values}))',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val <= n for n in {values}))'
+    },
+    FC_STRING_CONTAINS: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(s in val for s in {values}))',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(s in val for s in {values}))'
+    },
+    FC_STRING_DOES_NOT_CONTAIN: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(s not in val for s in {values}))', 
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(s not in val for s in {values}))'
+    },
+    FC_STRING_EXACTLY: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val == s for s in {values}))', 
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val == s for s in {values}))'
+    }, 
+    FC_STRING_NOT_EXACTLY: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val != s for s in {values}))',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val != s for s in {values}))'
+    },
+    FC_DATETIME_EXACTLY: {
+        'Or': '{df_name}[{transpiled_column_header}].isin({values})',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val == d for d in {values}))'
+    },
+    FC_DATETIME_NOT_EXACTLY: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val != d for d in {values}))',
+        'And': '~{df_name}[{transpiled_column_header}].isin({values})'
+    },
+    FC_DATETIME_GREATER: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val > d for d in {values}))',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val > d for d in {values}))'
+    },
+    FC_DATETIME_GREATER_THAN_OR_EQUAL: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val >= d for d in {values}))',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val >= d for d in {values}))'
+    },
+    FC_DATETIME_LESS: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val < d for d in {values}))',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val < d for d in {values}))'
+    },
+    FC_DATETIME_LESS_THAN_OR_EQUAL: {
+        'Or': '{df_name}[{transpiled_column_header}].apply(lambda val: any(val <= d for d in {values}))',
+        'And': '{df_name}[{transpiled_column_header}].apply(lambda val: all(val <= d for d in {values}))'
+    }
+}
+
+
+# If there are multiple conditions, we combine them together, with the
+# given operator in the middle
+OPERATOR_SIGNS = {
+    'Or': '|',
+    'And': '&'
+}
+
 class FilterStepPerformer(StepPerformer):
     """
     Allows you to filter a column based on some conditions and some values. 
@@ -152,6 +278,7 @@ class FilterStepPerformer(StepPerformer):
 
         return post_state, None
 
+
     @classmethod
     def transpile( # type: ignore
         cls,
@@ -165,27 +292,37 @@ class FilterStepPerformer(StepPerformer):
         **params
     ) -> List[str]:
         df_name = post_state.df_names[sheet_index]
-
         column_header = post_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+        column_mito_type = post_state.column_type[sheet_index][column_id]
+
+        filters_only = [filter_or_group for filter_or_group in filters if 'filters' not in filter_or_group]
+        filter_groups = [filter_or_group for filter_or_group in filters if 'filters' in filter_or_group]
 
         filter_strings = []
-        for filter_or_group in filters:
-            # If it is a group, we build the code for each filter, and then combine them at the end
-            if 'filters' in filter_or_group:
-                group_filter_strings = []
-                for filter_ in filter_or_group['filters']:
-                    group_filter_strings.append(
-                        get_filter_string(df_name, column_header, filter_)
-                    )
+        
+        # We loop over the filter conditions so we avoid looping over the filters and having to ensure 
+        # we don't see a filter condition twice
+        for filter_condition in FILTER_FORMAT_STRING_DICT.keys():            
+            filter_string = create_filter_string_for_condition(filter_condition, filters_only, df_name, column_header, operator, column_mito_type)
+            if filter_string != '':
+                filter_strings.append(filter_string)
 
-                filter_strings.append(
-                    # Note: we add parens around this, so it's grouped properly
-                    "(" + combine_filter_strings(filter_or_group['operator'], group_filter_strings) + ")"
-                )
-            else:
-                filter_strings.append(
-                    get_filter_string(df_name, column_header, filter_or_group)
-                )
+
+        for filter_group in filter_groups:
+            # If it is a group, we build the code for each filter condition, and then combine them at the end
+            group_filter_strings = []
+            for filter_condition in FILTER_FORMAT_STRING_DICT.keys():            
+                filter_string = create_filter_string_for_condition(filter_condition, filter_group['filters'], df_name, column_header, filter_group['operator'], column_mito_type)
+                if filter_string != '':
+                    group_filter_strings.append(filter_string)
+                
+            if len(group_filter_strings) == 0:
+                continue
+            
+            filter_strings.append(
+                # Note: we add parens around this, so it's grouped properly
+                "(" + combine_filter_strings(filter_group['operator'], group_filter_strings) + ")"
+            )
 
         if len(filter_strings) == 0:
             return []
@@ -358,7 +495,7 @@ def _execute_filter(
         return df
 
 
-def get_filter_string(df_name, column_header, filter_):
+def get_single_filter_string(df_name, column_header, filter_):
     """
     Transpiles a specific filter to a fitler string, to be used
     in constructing the final transpiled code
@@ -366,44 +503,34 @@ def get_filter_string(df_name, column_header, filter_):
     condition = filter_['condition']
     value = filter_['value']
 
-    FILTER_FORMAT_STRING_DICT = {
-        # SHARED CONDITIONS
-        FC_EMPTY: '{df_name}.{column_header}.isna()',
-        FC_NOT_EMPTY: '{df_name}.{column_header}.notnull()',
-
-        # BOOLEAN
-        FC_BOOLEAN_IS_TRUE: '{df_name}[\'{column_header}\'] == True',
-        FC_BOOLEAN_IS_FALSE: '{df_name}[\'{column_header}\'] == False',
-
-        # NUMBERS
-        FC_NUMBER_EXACTLY: '{df_name}[\'{column_header}\'] == {value}',
-        FC_NUMBER_NOT_EXACTLY: '{df_name}[\'{column_header}\'] != {value}',
-        FC_NUMBER_GREATER: '{df_name}[\'{column_header}\'] > {value}',
-        FC_NUMBER_GREATER_THAN_OR_EQUAL: '{df_name}[\'{column_header}\'] >= {value}',
-        FC_NUMBER_LESS: '{df_name}[\'{column_header}\'] < {value}',
-        FC_NUMBER_LESS_THAN_OR_EQUAL: '{df_name}[\'{column_header}\'] <= {value}',
-        
-        # STRINGS
-        FC_STRING_CONTAINS: '{df_name}[\'{column_header}\'].str.contains(\'{value}\', na=False)',
-        FC_STRING_DOES_NOT_CONTAIN: '~{df_name}[\'{column_header}\'].str.contains(\'{value}\', na=False)',
-        FC_STRING_EXACTLY: '{df_name}[\'{column_header}\'] == \'{value}\'',
-        FC_STRING_NOT_EXACTLY: '{df_name}[\'{column_header}\'] != \'{value}\'',
-
-        # DATES
-        FC_DATETIME_EXACTLY: '{df_name}[\'{column_header}\'] == pd.to_datetime(\'{value}\')',
-        FC_DATETIME_NOT_EXACTLY: '{df_name}[\'{column_header}\'] != pd.to_datetime(\'{value}\')',
-        FC_DATETIME_GREATER: '{df_name}[\'{column_header}\'] > pd.to_datetime(\'{value}\')',
-        FC_DATETIME_GREATER_THAN_OR_EQUAL: '{df_name}[\'{column_header}\'] >= pd.to_datetime(\'{value}\')',
-        FC_DATETIME_LESS: '{df_name}[\'{column_header}\'] < pd.to_datetime(\'{value}\')',
-        FC_DATETIME_LESS_THAN_OR_EQUAL: '{df_name}[\'{column_header}\'] <= pd.to_datetime(\'{value}\')',            
-    }
+    transpiled_column_header = column_header_to_transpiled_code(column_header)
 
     return FILTER_FORMAT_STRING_DICT[condition].format(
         df_name=df_name,
-        column_header=column_header,
+        transpiled_column_header=transpiled_column_header,
         value=value
     )
 
+def get_multiple_filter_string(df_name, column_header, original_operator, condition, column_mito_type, filters):
+    """
+    Transpiles a list of filters with the same filter condition to a filter string. 
+    """
+
+    # Handle dates specially by wrapping the number in a string and adding the pd.to_datetime call
+    if column_mito_type == DATETIME_SERIES:
+        values = [f'\'{filter["value"]}\'' for filter in filters]
+        values = 'pd.to_datetime(' + list_to_string_without_internal_quotes(values) + ')'
+    else:
+        values = [filter["value"] for filter in filters]
+
+    transpiled_column_header = column_header_to_transpiled_code(column_header)
+
+    return FILTER_FORMAT_STRING_MULTIPLE_VALUES_DICT[condition][original_operator].format( 
+        df_name=df_name,
+        transpiled_column_header=transpiled_column_header,
+        values=values,
+    )
+    
 def combine_filter_strings(operator, filter_strings, split_lines=False):
     """
     Combines the given filter strings with the passed operator, optionally 
@@ -415,12 +542,6 @@ def combine_filter_strings(operator, filter_strings, split_lines=False):
     if len(filter_strings) == 1:
         return filter_strings[0]
     else:
-        # If there are multiple conditions, we combine them together, with the
-        # given operator in the middle
-        OPERATOR_SIGNS = {
-            'Or': '|',
-            'And': '&'
-        }
         # Put parens around them
         filter_strings = [
             f'({fs})' for fs in filter_strings
@@ -439,4 +560,23 @@ def combine_filter_strings(operator, filter_strings, split_lines=False):
                 filter_string += ' \\\n\t'
                 current_line_length = 0
 
-        return filter_string
\ No newline at end of file
+
+        return filter_string
+
+def create_filter_string_for_condition(condition, mito_filters, df_name, column_header, operator, column_mito_type) -> str:
+    """
+    Returns a list of all the filter clauses for a specific filter condition in the list of passed filters
+    Note: We use the nomenclature "mito_filters" here so the compiler doesn't get confused when we use the filter function 
+    """
+    filters_with_condition = list(filter(lambda mito_filter: (mito_filter['condition'] == condition), mito_filters))
+
+    if len(filters_with_condition) == 0:
+        return ''
+    elif len(filters_with_condition) == 1:
+        # use the single filter condition
+        return get_single_filter_string(df_name, column_header, filters_with_condition[0])
+    elif len(filters_with_condition) > 1:
+        # use the multiple filter condition
+        return get_multiple_filter_string(df_name, column_header, operator, condition, column_mito_type, filters_with_condition)
+    
+    return ''
\ No newline at end of file
