@@ -6,12 +6,12 @@
 
 
 from copy import copy
+from mitosheet.errors import make_incompatible_merge_headers_error, make_incompatible_merge_key_error
 from typing import Any, Dict, List, Optional, Tuple
-from mitosheet.errors import make_incompatible_merge_key_error
-from mitosheet.sheet_functions.types.utils import get_mito_type
 from mitosheet.state import DATAFRAME_SOURCE_MERGED, State
 from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
+from mitosheet.transpiler.transpile_utils import column_header_list_to_transpiled_code, column_header_to_transpiled_code
+
 
 
 class MergeStepPerformer(StepPerformer):
@@ -122,12 +122,14 @@ class MergeStepPerformer(StepPerformer):
         deleted_columns_one = set(post_state.dfs[sheet_index_one].keys()).difference(set(selected_columns_one))
         deleted_columns_two = set(post_state.dfs[sheet_index_two].keys()).difference(set(selected_columns_two))
         if len(deleted_columns_one) > 0:
+            deleted_transpiled_column_header_one_list = column_header_list_to_transpiled_code(deleted_columns_one)
             merge_code.append(
-                f'{df_one_name}_tmp = {df_one_name}.drop({list(deleted_columns_one)}, axis=1)'
+                f'{df_one_name}_tmp = {df_one_name}.drop({deleted_transpiled_column_header_one_list}, axis=1)'
             )
         if len(deleted_columns_two) > 0:
+            deleted_transpiled_column_header_two_list = column_header_list_to_transpiled_code(deleted_columns_two)
             merge_code.append(
-                f'{df_two_name}_tmp = {temp_df_name}.drop({list(deleted_columns_two)}, axis=1)'
+                f'{df_two_name}_tmp = {temp_df_name}.drop({deleted_transpiled_column_header_two_list}, axis=1)'
             )
 
         # If we drop columns, we merge the new dataframes
@@ -181,6 +183,12 @@ def _execute_merge(
     Executes a merge on the sheets with the given indexes, merging on the 
     given keys, and only keeping the selection columns from each df.
     """
+    # We currently error if you try and merge two dataframes where they
+    # have different levels to the multi-index in the column headers. Aka, 
+    # you cannot merge a multi-index dataframe into a regular dataframe
+    if dfs[sheet_index_one].columns.nlevels != dfs[sheet_index_two].columns.nlevels:
+        raise make_incompatible_merge_headers_error(error_modal=False)
+
     if how == 'lookup':
         # We drop duplicates to avoid pairwise duplication on the merge.
         temp_df = dfs[sheet_index_two].drop_duplicates(subset=merge_key_two)
