@@ -10,6 +10,7 @@ from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.errors import (
     make_invalid_sort_error
 )
+from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
 
 # CONSTANTS USED IN THE SORT STEP ITSELF
 ASCENDING = 'ascending'
@@ -85,10 +86,12 @@ class SortStepPerformer(StepPerformer):
     ) -> List[str]:
         df_name = post_state.df_names[sheet_index]
         column_header = post_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+        transpiled_column_header = column_header_to_transpiled_code(column_header)
         
         na_position_string = 'first' if sort_direction == ASCENDING else 'last'
+        
         return [
-            f'{df_name} = {df_name}.sort_values(by=\'{column_header}\', ascending={sort_direction == ASCENDING}, na_position=\'{na_position_string}\')', 
+            f'{df_name} = {df_name}.sort_values(by={transpiled_column_header}, ascending={sort_direction == ASCENDING}, na_position=\'{na_position_string}\')', 
         ]
 
     @classmethod
