@@ -25,18 +25,20 @@ def test_transpile_multiple_columns_no_relationship():
     mito = create_mito_wrapper(['abc'])
     mito.add_column(0, 'B')
     mito.add_column(0, 'C')
-    code_container = transpile(mito.mito_widget.steps_manager)
-    
-    assert len([line for line in code_container['code'] if 'df1.insert(1, \'B\', 0)' in line]) > 0
-    assert len([line for line in code_container['code'] if 'df1.insert(2, \'C\', 0)' in line]) > 0
+    assert mito.transpiled_code == [
+        'df1.insert(1, \'B\', 0)',
+        'df1.insert(2, \'C\', 0)',
+    ]
 
 def test_transpile_columns_in_each_sheet():
     mito = create_mito_wrapper(['abc'], sheet_two_A_data=['abc'])
     mito.add_column(0, 'B')
     mito.add_column(1, 'B')
-    code_container = transpile(mito.mito_widget.steps_manager)
-    assert len([line for line in code_container['code'] if 'df1.insert(1, \'B\', 0)' in line]) > 0
-    assert len([line for line in code_container['code'] if 'df2.insert(1, \'B\', 0)' in line]) > 0
+
+    assert mito.transpiled_code == [
+        'df1.insert(1, \'B\', 0)',
+        'df2.insert(1, \'B\', 0)',
+    ]
 
 def test_transpile_multiple_columns_linear():
     mito = create_mito_wrapper(['abc'])
