@@ -8,8 +8,10 @@
 This file contains helpful functions and classes for testing operations.
 """
 
-import json
 from typing import List
+from mitosheet.utils import get_new_id
+from typing import List
+from functools import wraps
 
 import pandas as pd
 from mitosheet.mito_widget import MitoWidget, sheet
@@ -17,6 +19,77 @@ from mitosheet.transpiler.transpile import transpile
 from mitosheet.utils import get_new_id
 from mitosheet.api.get_sheet_data import get_sheet_data
 
+def decorate_all_functions(function_decorator):
+    """
+    Helper function to decorate all function
+    calls in a class
+    """
+    def decorator(cls):
+        for name, obj in vars(cls).items():
+            if callable(obj):
+                setattr(cls, name, function_decorator(obj))
+        return cls
+    return decorator
+
+
+def check_transpiled_code_after_call(func):
+    @wraps(func)
+    def wrapper(*args, **kw):
+        result = func(*args, **kw)
+        check_dataframes_equal(args[0])
+        return result
+    return wrapper
+
+
+def check_dataframes_equal(test_wrapper):
+    """
+    Tests that the dataframes in the widget state container equal
+    to those that are the result of the executed code. 
+    """
+
+    # The only dataframes we want to define apriori are the dataframes that
+    # were passed directly to the mito widget
+    original_dfs = {
+        df_name: df.copy(deep=True) for df, df_name in 
+        zip(
+            test_wrapper.mito_widget.steps_manager.original_args,
+            test_wrapper.mito_widget.steps_manager.steps[0].df_names
+        )
+    }
+    final_dfs = {
+        df_name: df.copy(deep=True) for df, df_name in 
+        zip(
+            test_wrapper.mito_widget.steps_manager.curr_step.dfs,
+            test_wrapper.mito_widget.steps_manager.curr_step.df_names
+        )
+    }
+
+    # Then, construct code that is just the code we expect, except at the end
+    # it compares the dataframe to the final dataframe we expect
+    def check_final_dataframe(df_name, df):
+        assert final_dfs[df_name].equals(df)
+
+    code = "\n".join(
+        test_wrapper.transpiled_code +
+        [
+            f'check_final_dataframe(\'{df_name}\', {df_name})'
+            for df_name in test_wrapper.mito_widget.steps_manager.curr_step.df_names
+        ]
+    )
+
+    import mitosheet
+    
+    exec(code, 
+        {
+            'check_final_dataframe': check_final_dataframe,
+            # Make sure all the mitosheet functions are defined, which replaces the
+            # `from mitosheet import *` code that is at the top of all
+            # transpiled code 
+            **mitosheet.__dict__ 
+        }, 
+        original_dfs
+    )
+
 
 class MitoWidgetTestWrapper:
     """
@@ -36,10 +109,27 @@ class MitoWidgetTestWrapper:
         # we don't have to change tests if we update comments
         return transpile(self.mito_widget.steps_manager, add_comments=False)['code']
 
+    @property
+    def curr_step_idx(self):
+        return self.mito_widget.steps_manager.curr_step_idx
+    
+    @property
+    def steps(self):
+        return self.mito_widget.steps_manager.steps
+
+    @property
+    def curr_step(self):
+        return self.mito_widget.steps_manager.curr_step
+    
     @property
     def dfs(self):
         return self.mito_widget.steps_manager.dfs
 
+    @property
+    def df_names(self):
+        return self.mito_widget.steps_manager.curr_step.df_names
+
+    @check_transpiled_code_after_call
     def add_column(self, sheet_index: int, column_header: str, column_header_index=-1):
         """
         Adds a column.
@@ -57,6 +147,7 @@ class MitoWidgetTestWrapper:
             }
         })
     
+    @check_transpiled_code_after_call
     def set_formula(
             self, 
             formula: str, 
@@ -91,6 +182,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def merge_sheets(
             self, 
             how,
@@ -138,16 +230,48 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
+    def drop_duplicates(
+            self, 
+            sheet_index, 
+            column_headers, 
+            keep,
+        ):
+
+        column_ids = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            for column_header in column_headers
+        ]
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'drop_duplicates_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_ids': column_ids,
+                    'keep': keep,
+                }
+            }
+        )
+
+    @check_transpiled_code_after_call
     def pivot_sheet(
             self, 
             sheet_index, 
             pivot_rows,
             pivot_columns,
             values,
+            flatten_column_headers=False,
             destination_sheet_index=None,
             step_id=None
         ):
 
+        print(flatten_column_headers)
+
         rows_ids = [
             self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
             for column_header in pivot_rows
@@ -173,11 +297,13 @@ class MitoWidgetTestWrapper:
                     'pivot_rows_column_ids': rows_ids,
                     'pivot_columns_column_ids': columns_ids,
                     'values_column_ids_map': values_column_ids_map,
-                    'destination_sheet_index': destination_sheet_index
+                    'destination_sheet_index': destination_sheet_index,
+                    'flatten_column_headers': flatten_column_headers
                 }
             }
         )
 
+    @check_transpiled_code_after_call
     def filter(
             self, 
             sheet_index, 
@@ -212,7 +338,9 @@ class MitoWidgetTestWrapper:
                 }
             }
         )
+
     
+    @check_transpiled_code_after_call
     def filters(
             self, 
             sheet_index, 
@@ -243,6 +371,7 @@ class MitoWidgetTestWrapper:
             }
         )
     
+    @check_transpiled_code_after_call
     def sort(
             self, 
             sheet_index, 
@@ -297,7 +426,8 @@ class MitoWidgetTestWrapper:
             }
         )
 
-    def rename_column(self, sheet_index: int, old_column_header: str, new_column_header):
+    @check_transpiled_code_after_call
+    def rename_column(self, sheet_index: int, old_column_header: str, new_column_header, level=None):
 
         column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
             sheet_index,
@@ -314,11 +444,13 @@ class MitoWidgetTestWrapper:
                 'params': {
                     'sheet_index': sheet_index,
                     'column_id': column_id,
-                    'new_column_header': new_column_header
+                    'new_column_header': new_column_header,
+                    'level': level
                 }
             }
         )
 
+    @check_transpiled_code_after_call
     def delete_columns(self, sheet_index: int, column_headers: List[str]):
         column_ids = [self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
             sheet_index,
@@ -339,6 +471,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def change_column_dtype(self, sheet_index: int, column_header: str, new_dtype: str):
 
         column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
@@ -361,6 +494,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def simple_import(self, file_names: List[str]):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -375,6 +509,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def excel_import(self, file_name: str, sheet_names: List[str], has_headers: bool, skiprows: int):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -392,6 +527,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def bulk_old_rename(self, move_to_deprecated_id_algorithm=False):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -406,7 +542,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
-    
+    @check_transpiled_code_after_call
     def undo(self):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -416,7 +552,8 @@ class MitoWidgetTestWrapper:
                 'type': 'undo'
             }
         )
-    
+
+    @check_transpiled_code_after_call
     def redo(self):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -427,6 +564,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def clear(self):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -437,6 +575,7 @@ class MitoWidgetTestWrapper:
             }
         )
     
+
     def save_analysis(self, analysis_name):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -473,6 +612,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def delete_dataframe(self, sheet_index):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -487,6 +627,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def duplicate_dataframe(self, sheet_index):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -501,6 +642,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def rename_dataframe(self, sheet_index, new_dataframe_name):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -516,6 +658,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def set_cell_value(self, sheet_index, column_header, row_index, new_value):
         column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
             sheet_index,
@@ -538,6 +681,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def replay_analysis(self, analysis_name, import_summaries=None, clear_existing_analysis=False):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -551,6 +695,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def checkout_step_by_idx(self, index):
         return self.mito_widget.receive_message(
             self.mito_widget,
@@ -623,6 +768,10 @@ class MitoWidgetTestWrapper:
         if as_list:
             return self.mito_widget.steps_manager.dfs[sheet_index][column_header].tolist()
         return self.mito_widget.steps_manager.dfs[sheet_index][column_header]
+
+    
+
+
         
 
 def create_mito_wrapper(sheet_one_A_data, sheet_two_A_data=None) -> MitoWidgetTestWrapper:
@@ -648,3 +797,37 @@ def create_mito_wrapper_dfs(*args):
     """
     mito_widget = sheet(*args)
     return MitoWidgetTestWrapper(mito_widget)
+
+def make_multi_index_header_df(data, column_headers, index=None):
+    """
+    A helper function that allows you to easily create a multi-index
+    header dataframe. 
+
+    Simply pass the data you want in the dataframe in a dictonary, and then 
+    a list of the column headers you want for each column in the data. 
+
+    At least one of the column headers should be a tuple, so that this
+    creates a multi-index header dataframe.
+
+    So: make_multi_index_header_df({0: ['a'], 1: ['b']}, ['header', ('header', 'other')]) 
+    will return a dataframe with the headers [('header', ''), ('header', 'other)].
+    """
+    df = pd.DataFrame(data=data)
+    max_length = 0
+    for column_header in column_headers:
+        if isinstance(column_header, tuple):
+            max_length = max(max_length, len(column_header))
+    
+    final_column_headers = []
+    for column_header in column_headers:
+        if isinstance(column_header, tuple):
+            final_column_headers.append(column_header)
+        else:
+            final_column_header = ['' for _ in range(max_length - 1)]
+            final_column_header.insert(0, column_header)
+            final_column_headers.append(tuple(final_column_header))
+
+    df.columns = pd.MultiIndex.from_tuples(final_column_headers)
+    if index is not None:
+        df.index = index
+    return df
