@@ -12,7 +12,7 @@ from copy import deepcopy
 from mitosheet import __version__
 from mitosheet.user import is_running_test
 from mitosheet.user.db import USER_JSON_PATH, get_user_field, get_user_json_object
-from mitosheet.user.schemas import UJ_MITOSHEET_TELEMETRY, USER_JSON_DEFAULT
+from mitosheet.user.schemas import UJ_FEEDBACKS_V2, UJ_MITOSHEET_TELEMETRY, USER_JSON_DEFAULT
 from mitosheet.user.schemas import (
     UJ_USER_JSON_VERSION, UJ_STATIC_USER_ID, UJ_USER_SALT, UJ_USER_EMAIL, 
     UJ_RECEIVED_TOURS, UJ_FEEDBACKS, UJ_MITOSHEET_CURRENT_VERSION, 
@@ -65,6 +65,7 @@ def check_user_json(
         user_email='github@action.com',
         received_tours=[],
         feedbacks=[],
+        feedbacks_v2={},
         mitosheet_current_version=__version__,
         mitosheet_last_upgraded_date=today_str,
         mitosheet_last_fifty_usages=[today_str],
@@ -77,12 +78,13 @@ def check_user_json(
     """
     assert set(get_user_json_object().keys()) == set(USER_JSON_DEFAULT.keys())
 
-    assert get_user_field(UJ_USER_JSON_VERSION) == 3
+    assert get_user_field(UJ_USER_JSON_VERSION) == 4
     assert len(get_user_field(UJ_STATIC_USER_ID)) > 0
     assert len(get_user_field(UJ_USER_SALT)) > 0
     assert (get_user_field(UJ_USER_EMAIL) == user_email or (get_user_field(UJ_USER_EMAIL) == 'github@action.com' and is_running_test()))
     assert get_user_field(UJ_RECEIVED_TOURS) == received_tours
     assert get_user_field(UJ_FEEDBACKS) == feedbacks
+    assert get_user_field(UJ_FEEDBACKS_V2) == feedbacks_v2
     assert get_user_field(UJ_MITOSHEET_CURRENT_VERSION) == mitosheet_current_version
     assert get_user_field(UJ_MITOSHEET_LAST_UPGRADED_DATE) == mitosheet_last_upgraded_date
     assert get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES) == mitosheet_last_fifty_usages
