@@ -25,6 +25,7 @@ from mitosheet.updates.rename_saved_analysis import RENAME_SAVED_ANALYSIS_UPDATE
 from mitosheet.updates.set_user_field_update import SET_USER_FIELD_UPDATE
 from mitosheet.updates.checkout_step_by_idx import CHECKOUT_STEP_BY_IDX_UPDATE
 from mitosheet.updates.append_user_field import APPEND_USER_FIELD_UPDATE
+from mitosheet.updates.update_feedback_v2_object import UPDATE_FEEDBACK_V2_OBJECT_UPDATE
 
 
 # All update events must be listed in this variable.
@@ -40,5 +41,6 @@ UPDATES = [
     CHECKOUT_STEP_BY_IDX_UPDATE,
     APPEND_USER_FIELD_UPDATE,
     SET_USER_FIELD_UPDATE,
-    CHECKOUT_STEP_BY_IDX_UPDATE
+    CHECKOUT_STEP_BY_IDX_UPDATE,
+    UPDATE_FEEDBACK_V2_OBJECT_UPDATE
 ]
\ No newline at end of file
