@@ -34,9 +34,16 @@ def execute_replay_analysis_update(
     If clear_existing_analysis is set to true, then this will clear the entire widget
     state container (except the initalize step) before applying the saved analysis.
     """ 
-    # We only keep the intialize step only
+
+    # We only keep the intialize step only, if we want to clear,
+    # and also update the analysis name to the replayed analysis
+    # NOTE: we update the analysis name so that when the code
+    # is written on the front-end, this analysis is correctly
+    # overwritten entirely (as this analysis being replayed entirely
+    # means that it is effectively being replaced)
     if clear_existing_analysis:
         steps_manager.steps = steps_manager.steps[:1]
+        steps_manager.analysis_name = analysis_name
 
     # If we're getting an event telling us to update, we read in the steps from the file
     analysis = read_and_upgrade_analysis(analysis_name)    
