@@ -27,6 +27,7 @@ UJ_USER_SALT = 'user_salt'
 UJ_USER_EMAIL = 'user_email'
 UJ_RECEIVED_TOURS = 'received_tours'
 UJ_FEEDBACKS = 'feedbacks'
+UJ_FEEDBACKS_V2 = 'feedbacks_v2'
 UJ_MITOSHEET_CURRENT_VERSION = 'mitosheet_current_version'
 UJ_MITOSHEET_LAST_UPGRADED_DATE = 'mitosheet_last_upgraded_date'
 UJ_MITOSHEET_LAST_FIFTY_USAGES = 'mitosheet_last_fifty_usages'
@@ -95,7 +96,69 @@ USER_JSON_VERSION_3 = {
     UJ_MITOSHEET_TELEMETRY: True
 }
 
+"""
+The only difference between version 3 and 4 is the addition of the UJ_FEEDBACKS_V2. 
+We moved to this format because we wanted to insist on more structure to our feedback, 
+allowing us to more intelligently extract information from the feedback object if we need to. 
+
+It has the format:
+{
+	"pivot_edit_usage_triggered": [
+		{
+			"date": "2021-11-16",
+			"num_usages": 1
+			"questions_and_answers": [
+				{
+					"question": "how successful was that pivot table?",
+					"answer":  5
+				},
+				{
+					"question": "what was your experience like",
+					"answer":  "It was difficult because ...", 
+				}
+			]
+		},
+		{
+			"date": "2021-11-17",
+			"num_usages": 2
+			"questions_and_answers": [
+				{
+					"question": "how successful was that pivot table?",
+					"answer":  5
+				},
+				{
+					"question": "what was your experience like",
+					"answer":  "It was difficult because ...", 
+				}
+			]
+		}
+	],
+	"other_feedback_id": [
+		...
+	]
+}
+"""
+USER_JSON_VERSION_4 = {
+    # The new version of the user json object
+    UJ_USER_JSON_VERSION: 4,
+    # The static id of the user
+    UJ_STATIC_USER_ID: get_random_id(),
+    # A random secret that the user can use as salt when hashing things
+    UJ_USER_SALT: get_random_id(),
+    # Email of the user
+    UJ_USER_EMAIL: '',
+    # Tours that the user has received
+    UJ_RECEIVED_TOURS: [],
+    # A list of all the feedback the user has given
+    UJ_FEEDBACKS: [],
+    UJ_FEEDBACKS_V2: {},
+    UJ_MITOSHEET_CURRENT_VERSION: __version__,
+    UJ_MITOSHEET_LAST_UPGRADED_DATE: datetime.today().strftime('%Y-%m-%d'),
+    UJ_MITOSHEET_LAST_FIFTY_USAGES: [datetime.today().strftime('%Y-%m-%d')],
+    UJ_MITOSHEET_TELEMETRY: True
+}
+
 
 # This is the most up to date user json, and you must update it when
 # you add a new schema
-USER_JSON_DEFAULT = USER_JSON_VERSION_3
\ No newline at end of file
+USER_JSON_DEFAULT = USER_JSON_VERSION_4
\ No newline at end of file
