@@ -32,7 +32,7 @@ the other.
 _Any change the user.json format must be met with a version bump._
 """
 from mitosheet.user.schemas import (
-    UJ_INTENDED_BEHAVIOR, UJ_CLOSED_FEEDBACK, UJ_MITOSHEET_LAST_FIVE_USAGES, UJ_MITOSHEET_TELEMETRY,
+    UJ_FEEDBACKS_V2, UJ_INTENDED_BEHAVIOR, UJ_CLOSED_FEEDBACK, UJ_MITOSHEET_LAST_FIVE_USAGES, UJ_MITOSHEET_TELEMETRY,
     UJ_USER_JSON_VERSION, UJ_MITOSHEET_LAST_FIFTY_USAGES
 )
 from mitosheet.user.schemas import USER_JSON_DEFAULT, USER_JSON_VERSION_1
@@ -107,6 +107,17 @@ def upgrade_user_json_version_2_to_3(user_json_version_2):
     user_json_version_2[UJ_MITOSHEET_TELEMETRY] = True
     return user_json_version_2
 
+def upgrade_user_json_version_3_to_4(user_json_version_3):
+    """
+    Just adds the user json feedback_v2 field
+    """
+    # First, bump the version number
+    user_json_version_3[UJ_USER_JSON_VERSION] = 4
+
+    # Then, set new field
+    user_json_version_3[UJ_FEEDBACKS_V2] = {}
+    return user_json_version_3
+
 def try_upgrade_user_json_to_current_version():
     user_json_object = get_user_json_object()
 
@@ -123,6 +134,8 @@ def try_upgrade_user_json_to_current_version():
         user_json_object = upgrade_final_user_json_version_1_to_2(user_json_object)
     if user_json_object[UJ_USER_JSON_VERSION] == 2:
         user_json_object = upgrade_user_json_version_2_to_3(user_json_object)
+    if user_json_object[UJ_USER_JSON_VERSION] == 3:
+        user_json_object = upgrade_user_json_version_3_to_4(user_json_object)
 
     set_user_json_object(user_json_object)
 
